A simple Calculator for general purposes.

The calculator has a memory that starts with the number 0 and can be manipulated until reset.

Commands :

Calculator.add 
Calculator.multiply 
Calculator.subtract 
Calculator.divide 
Calculator.nthroot 
Calculator.reset

Installation:
